
package com.agritrace.entity.domaine;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.jboss.seam.annotations.Name;

import com.agritrace.entity.entrepots.Entrepot;


@Entity
@Name("domaine")
public class Domaine implements Serializable {


	/**
	 * 
	 */
	private static final long serialVersionUID = -7561794761010020063L;


	@Id
    @GeneratedValue
    private Long idDomaine;

	
    @NotNull
    @Length(max=50)
    private String libelleDomaine;

    
    @NotNull
    @Length(max=10)
    private String numeroDomaine;

    
    @NotNull
    private double superficieTotale;

    
    private double superficieAbritee;
    
    
    private double profondeur;

    
    private String adresse;
    
    
    @Length(max=30)
    private String ville;
    

    private String observation;
    
    
    @NotNull
    @ManyToOne 
    @JoinColumn(name="idTypeSol")
    private TypeSol typeSol;
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="domaine")
	private Set<CertificationsDomaine> listeCertifications = new HashSet<CertificationsDomaine>();
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="domaine")
    private Set<Parcelle> listeParcelles = new HashSet<Parcelle>();
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="domaine")
    private Set<Entrepot> listeEntrepots = new HashSet<Entrepot>();
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="domaine")
    private Set<Toilette> listeToilettes = new HashSet<Toilette>();
    
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="domaine")
    private Set<ChateauEau> listeChateauxEau = new HashSet<ChateauEau>();
    
    
    public Domaine() {
		super();
		// TODO Auto-generated constructor stub
	}

    
	public Domaine(String libelleDomaine, String numeroDomaine,
			double superficieTotale, double superficieAbritee,
			double profondeur, String adresse, String ville,
			String observation, TypeSol typeSol,
			Set<CertificationsDomaine> listeCertifications,
			Set<Parcelle> listeParcelles, Set<Entrepot> listeEntrepots,
			Set<Toilette> listeToilettes, Set<ChateauEau> listeChateauxEau) {
		super();
		this.libelleDomaine = libelleDomaine;
		this.numeroDomaine = numeroDomaine;
		this.superficieTotale = superficieTotale;
		this.superficieAbritee = superficieAbritee;
		this.profondeur = profondeur;
		this.adresse = adresse;
		this.ville = ville;
		this.observation = observation;
		this.typeSol = typeSol;
		this.listeCertifications = listeCertifications;
		this.listeParcelles = listeParcelles;
		this.listeEntrepots = listeEntrepots;
		this.listeToilettes = listeToilettes;
		this.listeChateauxEau = listeChateauxEau;
	}


	public Set<CertificationsDomaine> getListeCertifications() {
		return listeCertifications;
	}


	public void setListeCertifications(
			Set<CertificationsDomaine> listeCertifications) {
		this.listeCertifications = listeCertifications;
	}


	public Set<Entrepot> getListeEntrepots() {
		return listeEntrepots;
	}


	public void setListeEntrepots(Set<Entrepot> listeEntrepots) {
		this.listeEntrepots = listeEntrepots;
	}


	public String getLibelleDomaine() {
		return libelleDomaine;
	}


	public void setLibelleDomaine(String libelleDomaine) {
		this.libelleDomaine = libelleDomaine;
	}


	public String getNumeroDomaine() {
		return numeroDomaine;
	}


	public void setNumeroDomaine(String numeroDomaine) {
		this.numeroDomaine = numeroDomaine;
	}


	public double getSuperficieTotale() {
		return superficieTotale;
	}


	public void setSuperficieTotale(double superficieTotale) {
		this.superficieTotale = superficieTotale;
	}


	public double getSuperficieAbritee() {
		return superficieAbritee;
	}


	public void setSuperficieAbritee(double superficieAbritee) {
		this.superficieAbritee = superficieAbritee;
	}


	public double getProfondeur() {
		return profondeur;
	}


	public void setProfondeur(double profondeur) {
		this.profondeur = profondeur;
	}


	public String getAdresse() {
		return adresse;
	}


	public void setAdresse(String adresse) {
		this.adresse = adresse;
	}


	public String getVille() {
		return ville;
	}


	public void setVille(String ville) {
		this.ville = ville;
	}


	public String getObservation() {
		return observation;
	}


	public void setObservation(String observation) {
		this.observation = observation;
	}


	public TypeSol getTypeSol() {
		return typeSol;
	}


	public void setTypeSol(TypeSol typeSol) {
		this.typeSol = typeSol;
	}


	public Set<Parcelle> getListeParcelles() {
		return listeParcelles;
	}


	public void setListeParcelles(Set<Parcelle> listeParcelles) {
		this.listeParcelles = listeParcelles;
	}


	public Set<Toilette> getListeToilettes() {
		return listeToilettes;
	}


	public void setListeToilettes(Set<Toilette> listeToilettes) {
		this.listeToilettes = listeToilettes;
	}


	public Set<ChateauEau> getListeChateauxEau() {
		return listeChateauxEau;
	}


	public void setListeChateauxEau(Set<ChateauEau> listeChateauxEau) {
		this.listeChateauxEau = listeChateauxEau;
	}


	public Long getIdDomaine() {
		return idDomaine;
	}

    
    

 }
