
package com.agritrace.entity.gestionCommercial;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.hibernate.validator.Past;
import org.jboss.seam.annotations.Name;

import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;
import com.agritrace.entity.tiers.Fournisseur;


@Entity
@Name("commande")
public class Commande implements Serializable
{
    

	/**
	 * 
	 */
	private static final long serialVersionUID = 8707294117826415818L;

	@Id
	@GeneratedValue
	private Long idCommande;
	
	
	@NotNull
	@Length(max=20)
    private String numeroCommande;

	
	@NotNull
	@Temporal(TemporalType.DATE)
	@Past
    private Date dateCommande;


    
	@NotNull
	@ManyToOne
	@JoinColumn(name="idCampagne")
    private Campagne campagne;
	
	
	@NotNull
	@ManyToOne
	@JoinColumn(name="idDomaine")
	private Domaine domaine;
	
	
	@NotNull
	@ManyToOne
	@JoinColumn(name="idTiers")
    private Fournisseur fournisseur;
    
	
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="commande")
    private Set<LigneCommande> lignesCommande = new HashSet<LigneCommande>();


    private String observation;


	public Commande() {
		super();
		// TODO Auto-generated constructor stub
	}

	public Commande(String numeroCommande, Date dateCommande,
			Campagne campagne, Domaine domaine, Fournisseur fournisseur,
			Set<LigneCommande> lignesCommande, String observation) {
		super();
		this.numeroCommande = numeroCommande;
		this.dateCommande = dateCommande;
		this.campagne = campagne;
		this.domaine = domaine;
		this.fournisseur = fournisseur;
		this.lignesCommande = lignesCommande;
		this.observation = observation;
	}

	public boolean isSatisfied()
	{	
		if(this.lignesCommande.size()!=0)
		{
			for(LigneCommande ligneCommande : this.lignesCommande)
			{
				//si une au moins une ligne de commande n'a pas été safistaite ==> on sorts de la méthode et 
				//on retourne FALSE ====> Commande non satifaite
				if(ligneCommande.getTotalReception()<ligneCommande.getQteCommandee())
				{
					return false;
				}
			}
		}
		
		return true;
	}
	
	public Domaine getDomaine() {
		return domaine;
	}

	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}

	public String getNumeroCommande() {
		return numeroCommande;
	}


	public void setNumeroCommande(String numeroCommande) {
		this.numeroCommande = numeroCommande;
	}


	public Date getDateCommande() {
		return dateCommande;
	}


	public void setDateCommande(Date dateCommande) {
		this.dateCommande = dateCommande;
	}


	public Campagne getCampagne() {
		return campagne;
	}


	public void setCampagne(Campagne campagne) {
		this.campagne = campagne;
	}


	public Fournisseur getFournisseur() {
		return fournisseur;
	}


	public void setFournisseur(Fournisseur fournisseur) {
		this.fournisseur = fournisseur;
	}


	public Set<LigneCommande> getLignesCommande() {
		return lignesCommande;
	}


	public void setLignesCommande(Set<LigneCommande> lignesCommande) {
		this.lignesCommande = lignesCommande;
	}


	public String getObservation() {
		return observation;
	}


	public void setObservation(String observation) {
		this.observation = observation;
	}


	public Long getIdCommande() {
		return idCommande;
	}

    
}
