
package com.agritrace.entity.production;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.jboss.seam.annotations.Name;
import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;


@Entity
@Name("intervention")
public class Intervention implements Serializable
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 4102951590425191365L;

	@Id 
	@GeneratedValue
    private Long idIntervention;


	@NotNull
	@Length(max=20)
    private String numeroIntervention;


	@NotNull
	@Temporal(TemporalType.TIMESTAMP)
    private Date heureDebutIntervention;


	@NotNull
	@Temporal(TemporalType.TIMESTAMP)
    private Date heureFinIntervention;
    
 
	private double debitEau;
	
    
	@Length(max=40)
    private String stadePhenologique;
    
    /////////////////////////////Information meteorologique/////////  
    
    private int pluviometrie;
    
    private int temperature;
    
    private int hygrometrie;
    
    private int vitesseVent;
    
    //////////////////////////////////////////////////////////////////
    
	@NotNull
	@ManyToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="idCampagne")
    private Campagne campagne;
	
	@NotNull
	@ManyToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="idDomaine")
    private Domaine domaine;
	
	
    @ManyToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="idOrdreIntervention")
    private OrdreIntervention ordreIntervention;
    
    
    @ManyToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="idOperation")
    private Operation operation;
	
	
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
	private Set<DetailsInterventionParcelleCulturale> detailsInterventionParcelleCulturales=new HashSet<DetailsInterventionParcelleCulturale>();
	
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
    private Set<DetailsInterventionMo> detailsInterventionMo = new HashSet<DetailsInterventionMo>();
   
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
    private Set<DetailsInterventionCategorieMo> detailsInterventionCategorieMo = new HashSet<DetailsInterventionCategorieMo>();
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
    private Set<DetailsInterventionMateriel> detailsInterventionMateriel = new HashSet<DetailsInterventionMateriel>();
    
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
    private Set<DetailsInterventionOutillage> detailsInterventioOutillage = new HashSet<DetailsInterventionOutillage>();
    
    
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="intervention")
	private Set<DetailsInterventionProduits> detailsInterventionProduits=new HashSet<DetailsInterventionProduits>();
    
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH}, fetch=FetchType.LAZY, mappedBy="intervention")
    private Set<CiblesTraitementPhyto> ciblesTraitementPhytos = new HashSet<CiblesTraitementPhyto>();
	
	private String observation;
	
	
	public Intervention() {
		super();
		// TODO Auto-generated constructor stub
	}

	public String getInstanceOfIntervention()
	{
		String instanceType="";
		
		if(this instanceof NettoyageToilette)
		{
			instanceType="Nettoyage des Toilette";
		}
		else if(this instanceof NettoyageChateauEau)
		{
			instanceType="Nettoyage des Chateau des eaux";
		}
		else if(this instanceof AnalyseEau)
		{
			instanceType="Analyse Eau";
		}
		else if(this instanceof AnalyseSol)
		{
			instanceType="Analyse Sol";
		}			
		else if(this instanceof AnalysePlantes)
		{
			instanceType="Analyse Plantes";
		}
		else if(this instanceof Recolte)
		{
			instanceType="Récolte";
		}
		return instanceType;
	}
	
	public Intervention(
			String numeroIntervention,
			Date heureDebutIntervention,
			Date heureFinIntervention,
			double debitEau,
			String stadePhenologique,
			int pluviometrie,
			int temperature,
			int hygrometrie,
			int vitesseVent,
			Campagne campagne,
			Domaine domaine,
			OrdreIntervention ordreIntervention,
			Operation operation,
			Set<DetailsInterventionParcelleCulturale> detailsInterventionParcelleCulturales,
			Set<DetailsInterventionMo> detailsInterventionMo,
			Set<DetailsInterventionCategorieMo> detailsInterventionCategorieMo,
			Set<DetailsInterventionMateriel> detailsInterventionMateriel,
			Set<DetailsInterventionOutillage> detailsInterventioOutillage,
			Set<DetailsInterventionProduits> detailsInterventionProduits,
			Set<CiblesTraitementPhyto> ciblesTraitementPhytos,
			String observation) {
		super();
		this.numeroIntervention = numeroIntervention;
		this.heureDebutIntervention = heureDebutIntervention;
		this.heureFinIntervention = heureFinIntervention;
		this.debitEau = debitEau;
		this.stadePhenologique = stadePhenologique;
		this.pluviometrie = pluviometrie;
		this.temperature = temperature;
		this.hygrometrie = hygrometrie;
		this.vitesseVent = vitesseVent;
		this.campagne = campagne;
		this.domaine = domaine;
		this.ordreIntervention = ordreIntervention;
		this.operation = operation;
		this.detailsInterventionParcelleCulturales = detailsInterventionParcelleCulturales;
		this.detailsInterventionMo = detailsInterventionMo;
		this.detailsInterventionCategorieMo = detailsInterventionCategorieMo;
		this.detailsInterventionMateriel = detailsInterventionMateriel;
		this.detailsInterventioOutillage = detailsInterventioOutillage;
		this.detailsInterventionProduits = detailsInterventionProduits;
		this.ciblesTraitementPhytos = ciblesTraitementPhytos;
		this.observation = observation;
	}

	public Domaine getDomaine() {
		return domaine;
	}

	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}

	public Set<DetailsInterventionCategorieMo> getDetailsInterventionCategorieMo() {
		return detailsInterventionCategorieMo;
	}

	public void setDetailsInterventionCategorieMo(
			Set<DetailsInterventionCategorieMo> detailsInterventionCategorieMo) {
		this.detailsInterventionCategorieMo = detailsInterventionCategorieMo;
	}

	public String getStadePhenologique() {
		return stadePhenologique;
	}


	public void setStadePhenologique(String stadePhenologique) {
		this.stadePhenologique = stadePhenologique;
	}


	public Set<CiblesTraitementPhyto> getCiblesTraitementPhytos() {
		return ciblesTraitementPhytos;
	}

	public void setCiblesTraitementPhytos(
			Set<CiblesTraitementPhyto> ciblesTraitementPhytos) {
		this.ciblesTraitementPhytos = ciblesTraitementPhytos;
	}

	public int getPluviometrie() {
		return pluviometrie;
	}

	public void setPluviometrie(int pluviometrie) {
		this.pluviometrie = pluviometrie;
	}

	public int getTemperature() {
		return temperature;
	}

	public void setTemperature(int temperature) {
		this.temperature = temperature;
	}

	public int getHygrometrie() {
		return hygrometrie;
	}

	public void setHygrometrie(int hygrometrie) {
		this.hygrometrie = hygrometrie;
	}

	public int getVitesseVent() {
		return vitesseVent;
	}

	public void setVitesseVent(int vitesseVent) {
		this.vitesseVent = vitesseVent;
	}

	public String getObservation() {
		return observation;
	}

	public void setObservation(String observation) {
		this.observation = observation;
	}

	public Campagne getCampagne() {
		return campagne;
	}


	public void setCampagne(Campagne campagne) {
		this.campagne = campagne;
	}


	public Set<DetailsInterventionParcelleCulturale> getDetailsInterventionParcelleCulturales() {
		return detailsInterventionParcelleCulturales;
	}


	public void setDetailsInterventionParcelleCulturales(
			Set<DetailsInterventionParcelleCulturale> detailsInterventionParcelleCulturales) {
		this.detailsInterventionParcelleCulturales = detailsInterventionParcelleCulturales;
	}


	public Operation getOperation() {
		return operation;
	}



	public void setOperation(Operation operation) {
		this.operation = operation;
	}

	public Set<DetailsInterventionProduits> getDetailsInterventionProduits() {
		return detailsInterventionProduits;
	}



	public void setDetailsInterventionProduits(
			Set<DetailsInterventionProduits> detailsInterventionProduits) {
		this.detailsInterventionProduits = detailsInterventionProduits;
	}



	public String getNumeroIntervention() {
		return numeroIntervention;
	}


	public void setNumeroIntervention(String numeroIntervention) {
		this.numeroIntervention = numeroIntervention;
	}


	public Date getHeureDebutIntervention() {
		return heureDebutIntervention;
	}


	public void setHeureDebutIntervention(Date heureDebutIntervention) {
		this.heureDebutIntervention = heureDebutIntervention;
	}


	public Date getHeureFinIntervention() {
		return heureFinIntervention;
	}


	public void setHeureFinIntervention(Date heureFinIntervention) {
		this.heureFinIntervention = heureFinIntervention;
	}


	public OrdreIntervention getOrdreIntervention() {
		return ordreIntervention;
	}


	public void setOrdreIntervention(OrdreIntervention ordreIntervention) {
		this.ordreIntervention = ordreIntervention;
	}


	public Set<DetailsInterventionMo> getDetailsInterventionMo() {
		return detailsInterventionMo;
	}


	public void setDetailsInterventionMo(
			Set<DetailsInterventionMo> detailsInterventionMo) {
		this.detailsInterventionMo = detailsInterventionMo;
	}


	public Set<DetailsInterventionMateriel> getDetailsInterventionMateriel() {
		return detailsInterventionMateriel;
	}


	public void setDetailsInterventionMateriel(
			Set<DetailsInterventionMateriel> detailsInterventionMateriel) {
		this.detailsInterventionMateriel = detailsInterventionMateriel;
	}


	public Set<DetailsInterventionOutillage> getDetailsInterventioOutillage() {
		return detailsInterventioOutillage;
	}


	public void setDetailsInterventioOutillage(
			Set<DetailsInterventionOutillage> detailsInterventioOutillage) {
		this.detailsInterventioOutillage = detailsInterventioOutillage;
	}


	public Long getIdIntervention() {
		return idIntervention;
	}


	public double getDebitEau() {
		return debitEau;
	}


	public void setDebitEau(double debitEau) {
		this.debitEau = debitEau;
	}
 }
