
package com.agritrace.entity.production;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.jboss.seam.annotations.Name;

import com.agritrace.entity.articles.Materiel;
import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;
import com.agritrace.entity.tiers.Personnel;


@Entity
@Name("Maintenance")
public class Maintenance implements Serializable
{


	/**
	 * 
	 */
	private static final long serialVersionUID = 8501163011123324290L;

	
	@Id 
	@GeneratedValue
    private Long idMaintenance;


	@NotNull
	@Length(max=20)
    private String numeroMaintenance;


	@NotNull
	@Temporal(TemporalType.TIMESTAMP)
    private Date heureDebutMaintenance;


	@NotNull
	@Temporal(TemporalType.TIMESTAMP)
    private Date heureFinMaintenance;
    
 
    @ManyToOne
    @JoinColumn(name="idOrdreIntervention")
    private OrdreIntervention ordreIntervention;
   
	
	@NotNull
    @ManyToOne
    @JoinColumn(name="idTiers")
    private Personnel personnel;
	
	
	@NotNull
    @ManyToOne
    @JoinColumn(name="idCampagne")
    private Campagne campagne;
	
	@NotNull
	@ManyToOne
	@JoinColumn(name="idDomaine")
	private Domaine domaine;
	
	@NotNull
    @ManyToOne
    @JoinColumn(name="idArticle")
    private Materiel materiel;
    
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="maintenance")
    private Set<DetailsOutillageUtilise> detailsOutillageUtilise = new HashSet<DetailsOutillageUtilise>();

    
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="maintenance")
	private Set<DetailsProduitsMaintenance> detailsProduitsMaintenance=new HashSet<DetailsProduitsMaintenance>();
	

	@NotNull
	private boolean efficace;


	@NotNull
	@Length(max=20)
    private String typeMaintenance;    ///====> 1 : préventive ; 2 : corrective

	
	@NotNull			
	@Length(max=20)
	private String natureMaintenance;  ///====> (1)Mécanique, (2)Pneumatique, (3)Hydrualique, (4)Electrique, (5)Electronique, (6)Autres

	
	
    private String travailEffectue;
	
	
	

	public Maintenance() {
		super();
		// TODO Auto-generated constructor stub
	}

	public Maintenance(String numeroMaintenance, Date heureDebutMaintenance,
			Date heureFinMaintenance, OrdreIntervention ordreIntervention,
			Personnel personnel, Campagne campagne, Domaine domaine,
			Materiel materiel,
			Set<DetailsOutillageUtilise> detailsOutillageUtilise,
			Set<DetailsProduitsMaintenance> detailsProduitsMaintenance,
			boolean efficace, String typeMaintenance, String natureMaintenance,
			String travailEffectue) {
		super();
		this.numeroMaintenance = numeroMaintenance;
		this.heureDebutMaintenance = heureDebutMaintenance;
		this.heureFinMaintenance = heureFinMaintenance;
		this.ordreIntervention = ordreIntervention;
		this.personnel = personnel;
		this.campagne = campagne;
		this.domaine = domaine;
		this.materiel = materiel;
		this.detailsOutillageUtilise = detailsOutillageUtilise;
		this.detailsProduitsMaintenance = detailsProduitsMaintenance;
		this.efficace = efficace;
		this.typeMaintenance = typeMaintenance;
		this.natureMaintenance = natureMaintenance;
		this.travailEffectue = travailEffectue;
	}

	
	public Domaine getDomaine() {
		return domaine;
	}

	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}

	public String getNumeroMaintenance() {
		return numeroMaintenance;
	}




	public void setNumeroMaintenance(String numeroMaintenance) {
		this.numeroMaintenance = numeroMaintenance;
	}




	public Date getHeureDebutMaintenance() {
		return heureDebutMaintenance;
	}




	public void setHeureDebutMaintenance(Date heureDebutMaintenance) {
		this.heureDebutMaintenance = heureDebutMaintenance;
	}




	public Date getHeureFinMaintenance() {
		return heureFinMaintenance;
	}




	public void setHeureFinMaintenance(Date heureFinMaintenance) {
		this.heureFinMaintenance = heureFinMaintenance;
	}




	public OrdreIntervention getOrdreIntervention() {
		return ordreIntervention;
	}




	public void setOrdreIntervention(OrdreIntervention ordreIntervention) {
		this.ordreIntervention = ordreIntervention;
	}




	public Personnel getPersonnel() {
		return personnel;
	}




	public void setPersonnel(Personnel personnel) {
		this.personnel = personnel;
	}




	public Campagne getCampagne() {
		return campagne;
	}




	public void setCampagne(Campagne campagne) {
		this.campagne = campagne;
	}




	public Materiel getMateriel() {
		return materiel;
	}




	public void setMateriel(Materiel materiel) {
		this.materiel = materiel;
	}




	public Set<DetailsOutillageUtilise> getDetailsOutillageUtilise() {
		return detailsOutillageUtilise;
	}




	public void setDetailsOutillageUtilise(
			Set<DetailsOutillageUtilise> detailsOutillageUtilise) {
		this.detailsOutillageUtilise = detailsOutillageUtilise;
	}




	public Set<DetailsProduitsMaintenance> getDetailsProduitsMaintenance() {
		return detailsProduitsMaintenance;
	}




	public void setDetailsProduitsMaintenance(
			Set<DetailsProduitsMaintenance> detailsProduitsMaintenance) {
		this.detailsProduitsMaintenance = detailsProduitsMaintenance;
	}




	public boolean isEfficace() {
		return efficace;
	}




	public void setEfficace(boolean efficace) {
		this.efficace = efficace;
	}




	public String getTypeMaintenance() {
		return typeMaintenance;
	}




	public void setTypeMaintenance(String typeMaintenance) {
		this.typeMaintenance = typeMaintenance;
	}




	public String getNatureMaintenance() {
		return natureMaintenance;
	}




	public void setNatureMaintenance(String natureMaintenance) {
		this.natureMaintenance = natureMaintenance;
	}




	public String getTravailEffectue() {
		return travailEffectue;
	}




	public void setTravailEffectue(String travailEffectue) {
		this.travailEffectue = travailEffectue;
	}




	public Long getIdMaintenance() {
		return idMaintenance;
	}


	



	

 }
