
package com.agritrace.entity.production;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.jboss.seam.annotations.Name;

import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;




@Entity
@Name("ordreIntervention")
public class OrdreIntervention implements Serializable {


	
	/**
	 * 
	 */
	private static final long serialVersionUID = -6492249556901388734L;


	@Id 
	@GeneratedValue
    private Long idOrdreIntervention;


	@NotNull
	@Length(max=20)
    private String numeroOrdreIntervention;

	
    private String travailAEffectuer;


    private String probleme;


    @NotNull
    @Temporal(TemporalType.TIMESTAMP)
    private Date dateHeureOrdre;

    
    @NotNull
    @Length(max=20)
    private String priorite;
    
    
    @Length(max=30)
    private String typeOrdreIntervention;    
    
    
    ////Optionnelle : peut être reseigné ds le cas d'une analyse de plants et déclenchante un 
	////// ordre d'interention
    
    @ManyToOne
    @JoinColumn(name="idIntervention")
    private Analyse analyse;    
    
    
    @NotNull
    @ManyToOne
    @JoinColumn(name="idCampagne")
    private Campagne campagne;

    
	@NotNull
    @ManyToOne
    @JoinColumn(name="idDomaine")
    private Domaine domaine;
    
    
    private boolean ordreExecute;


    @ManyToOne(fetch=FetchType.LAZY)
    @JoinColumn(name="idOperation")
    private Operation operation;
    
    
    
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
	private Set<DetailsOrdreParcelleCulturale> detailsOrdreParcelleCulturales=new HashSet<DetailsOrdreParcelleCulturale>();
	
	
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
    private Set<DetailsOrdreMainOeuvre> detailsOrdreMainOeuvre = new HashSet<DetailsOrdreMainOeuvre>();
   
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
    private Set<DetailsOrdreCategorieMo> detailsOrdreCategorieMo = new HashSet<DetailsOrdreCategorieMo>();
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
    private Set<DetailsOrdreMateriel> detailsOrdreMateriel = new HashSet<DetailsOrdreMateriel>();
    
    
    @OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
    private Set<DetailsOrdreOutillage> detailsOrdreOutillage = new HashSet<DetailsOrdreOutillage>();
    
    
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="ordreIntervention")
	private Set<DetailsOrdreProduits> detailsOrdreProduits=new HashSet<DetailsOrdreProduits>();
    
    
	
	public OrdreIntervention() {
		super();
		// TODO Auto-generated constructor stub
	}

	
	public OrdreIntervention(String numeroOrdreIntervention,
			String travailAEffectuer, String probleme, Date dateHeureOrdre,
			String priorite, String typeOrdreIntervention, Analyse analyse,
			Campagne campagne, Domaine domaine, boolean ordreExecute,
			Operation operation,
			Set<DetailsOrdreParcelleCulturale> detailsOrdreParcelleCulturales,
			Set<DetailsOrdreMainOeuvre> detailsOrdreMainOeuvre,
			Set<DetailsOrdreCategorieMo> detailsOrdreCategorieMo,
			Set<DetailsOrdreMateriel> detailsOrdreMateriel,
			Set<DetailsOrdreOutillage> detailsOrdreOutillage,
			Set<DetailsOrdreProduits> detailsOrdreProduits) {
		super();
		this.numeroOrdreIntervention = numeroOrdreIntervention;
		this.travailAEffectuer = travailAEffectuer;
		this.probleme = probleme;
		this.dateHeureOrdre = dateHeureOrdre;
		this.priorite = priorite;
		this.typeOrdreIntervention = typeOrdreIntervention;
		this.analyse = analyse;
		this.campagne = campagne;
		this.domaine = domaine;
		this.ordreExecute = ordreExecute;
		this.operation = operation;
		this.detailsOrdreParcelleCulturales = detailsOrdreParcelleCulturales;
		this.detailsOrdreMainOeuvre = detailsOrdreMainOeuvre;
		this.detailsOrdreCategorieMo = detailsOrdreCategorieMo;
		this.detailsOrdreMateriel = detailsOrdreMateriel;
		this.detailsOrdreOutillage = detailsOrdreOutillage;
		this.detailsOrdreProduits = detailsOrdreProduits;
	}


	public Operation getOperation() {
		return operation;
	}


	public void setOperation(Operation operation) {
		this.operation = operation;
	}


	public Set<DetailsOrdreParcelleCulturale> getDetailsOrdreParcelleCulturales() {
		return detailsOrdreParcelleCulturales;
	}


	public void setDetailsOrdreParcelleCulturales(
			Set<DetailsOrdreParcelleCulturale> detailsOrdreParcelleCulturales) {
		this.detailsOrdreParcelleCulturales = detailsOrdreParcelleCulturales;
	}


	public Set<DetailsOrdreMainOeuvre> getDetailsOrdreMainOeuvre() {
		return detailsOrdreMainOeuvre;
	}


	public void setDetailsOrdreMainOeuvre(
			Set<DetailsOrdreMainOeuvre> detailsOrdreMainOeuvre) {
		this.detailsOrdreMainOeuvre = detailsOrdreMainOeuvre;
	}


	public Set<DetailsOrdreCategorieMo> getDetailsOrdreCategorieMo() {
		return detailsOrdreCategorieMo;
	}


	public void setDetailsOrdreCategorieMo(
			Set<DetailsOrdreCategorieMo> detailsOrdreCategorieMo) {
		this.detailsOrdreCategorieMo = detailsOrdreCategorieMo;
	}


	public Set<DetailsOrdreMateriel> getDetailsOrdreMateriel() {
		return detailsOrdreMateriel;
	}


	public void setDetailsOrdreMateriel(
			Set<DetailsOrdreMateriel> detailsOrdreMateriel) {
		this.detailsOrdreMateriel = detailsOrdreMateriel;
	}


	public Set<DetailsOrdreOutillage> getDetailsOrdreOutillage() {
		return detailsOrdreOutillage;
	}


	public void setDetailsOrdreOutillage(
			Set<DetailsOrdreOutillage> detailsOrdreOutillage) {
		this.detailsOrdreOutillage = detailsOrdreOutillage;
	}


	public Set<DetailsOrdreProduits> getDetailsOrdreProduits() {
		return detailsOrdreProduits;
	}


	public void setDetailsOrdreProduits(
			Set<DetailsOrdreProduits> detailsOrdreProduits) {
		this.detailsOrdreProduits = detailsOrdreProduits;
	}


	public Domaine getDomaine() {
		return domaine;
	}


	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}


	public boolean isOrdreExecute() {
		return ordreExecute;
	}


	public void setOrdreExecute(boolean ordreExecute) {
		this.ordreExecute = ordreExecute;
	}


	public String getPriorite() {
		return priorite;
	}

	public String getTypeOrdreIntervention() {
		return typeOrdreIntervention;
	}

	public void setPriorite(String priorite) {
		this.priorite = priorite;
	}

	public void setTypeOrdreIntervention(String typeOrdreIntervention) {
		this.typeOrdreIntervention = typeOrdreIntervention;
	}

	public String getNumeroOrdreIntervention() {
		return numeroOrdreIntervention;
	}



	public void setNumeroOrdreIntervention(String numeroOrdreIntervention) {
		this.numeroOrdreIntervention = numeroOrdreIntervention;
	}



	public String getTravailAEffectuer() {
		return travailAEffectuer;
	}



	public void setTravailAEffectuer(String travailAEffectuer) {
		this.travailAEffectuer = travailAEffectuer;
	}



	public String getProbleme() {
		return probleme;
	}



	public void setProbleme(String probleme) {
		this.probleme = probleme;
	}



	public Date getDateHeureOrdre() {
		return dateHeureOrdre;
	}



	public void setDateHeureOrdre(Date dateHeureOrdre) {
		this.dateHeureOrdre = dateHeureOrdre;
	}

	public Analyse getAnalyse() {
		return analyse;
	}



	public void setAnalyse(Analyse analyse) {
		this.analyse = analyse;
	}



	public Campagne getCampagne() {
		return campagne;
	}



	public void setCampagne(Campagne campagne) {
		this.campagne = campagne;
	}



	public Long getIdOrdreIntervention() {
		return idOrdreIntervention;
	}

    
 }
