
package com.agritrace.entity.tiers;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.hibernate.validator.Length;
import org.hibernate.validator.NotNull;
import org.hibernate.validator.Past;
import org.jboss.seam.annotations.Name;

import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;

@Entity
@Name("formation")
public class Formation implements Serializable
{

	
	/**
	 * 
	 */
	private static final long serialVersionUID = -7916965339251135781L;


	@Id
	@GeneratedValue
	private Long idFormation;
	
	
	@NotNull
	@Length(max=20)
	private String numeroFormation;
	
	
	@NotNull
	@Temporal(TemporalType.DATE)
	@Past
	private Date dateDebutFormation;

	
	@NotNull
	@Temporal(TemporalType.DATE)
	private Date dateFinFormation;
	
	
    private String description; 

	
    @NotNull
	@ManyToOne
	@JoinColumn(name="idCampagne")
    private Campagne campagne;

    
	@NotNull
	@ManyToOne
	@JoinColumn(name="idDomaine")
	private Domaine domaine;
	
	
	@NotNull
	@ManyToOne
	@JoinColumn(name="idTuteur")
	private Personnel personnel;
	
	
	private double montantFormation;
	
	
	@OneToMany(cascade = {CascadeType.MERGE,CascadeType.REMOVE,CascadeType.REFRESH} , fetch = FetchType.LAZY , mappedBy="formation")
    private Set<PersonnelFormation> AffectationsPersonnelFormation = new HashSet<PersonnelFormation>();

	
	public Formation() {
		super();
		// TODO Auto-generated constructor stub
	}


	public Formation(String numeroFormation, Date dateDebutFormation,
			Date dateFinFormation, String description, Campagne campagne,
			Domaine domaine, Personnel personnel, double montantFormation,
			Set<PersonnelFormation> affectationsPersonnelFormation) {
		super();
		this.numeroFormation = numeroFormation;
		this.dateDebutFormation = dateDebutFormation;
		this.dateFinFormation = dateFinFormation;
		this.description = description;
		this.campagne = campagne;
		this.domaine = domaine;
		this.personnel = personnel;
		this.montantFormation = montantFormation;
		AffectationsPersonnelFormation = affectationsPersonnelFormation;
	}

	
	public Personnel getPersonnel() {
		return personnel;
	}


	public void setPersonnel(Personnel personnel) {
		this.personnel = personnel;
	}


	public double getMontantFormation() {
		return montantFormation;
	}


	public void setMontantFormation(double montantFormation) {
		this.montantFormation = montantFormation;
	}


	public Domaine getDomaine() {
		return domaine;
	}

	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}


	public Set<PersonnelFormation> getAffectationsPersonnelFormation() {
		return AffectationsPersonnelFormation;
	}





	public void setAffectationsPersonnelFormation(
			Set<PersonnelFormation> affectationsPersonnelFormation) {
		AffectationsPersonnelFormation = affectationsPersonnelFormation;
	}





	public String getNumeroFormation() {
		return numeroFormation;
	}


	public void setNumeroFormation(String numeroFormation) {
		this.numeroFormation = numeroFormation;
	}


	public Date getDateDebutFormation() {
		return dateDebutFormation;
	}


	public void setDateDebutFormation(Date dateDebutFormation) {
		this.dateDebutFormation = dateDebutFormation;
	}


	public Date getDateFinFormation() {
		return dateFinFormation;
	}


	public void setDateFinFormation(Date dateFinFormation) {
		this.dateFinFormation = dateFinFormation;
	}


	public String getDescription() {
		return description;
	}


	public void setDescription(String description) {
		this.description = description;
	}


	public Campagne getCampagne() {
		return campagne;
	}


	public void setCampagne(Campagne campagne) {
		this.campagne = campagne;
	}


	public Long getIdFormation() {
		return idFormation;
	}
	

	
 }
