package com.agritrace.session;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.CaisseRamassage;
import com.agritrace.entity.articles.InventaireClientCaisses;
import com.agritrace.entity.unitesMesure.UniteMesure;

@Name("caisseRamassageHome")
public class CaisseRamassageHome extends ArticleHome<CaisseRamassage> {

	@Logger
	Log log;
	
	@In
	EntityManager entityManager;
	
	public void setCaisseRamassageIdArticle(Long id) {
		setId(id);
	}

	public Long getCaisseRamassageIdArticle() {
		return (Long) getId();
	}

	@Override
	protected CaisseRamassage createInstance() {
		CaisseRamassage caisseRamassage = new CaisseRamassage();
		return caisseRamassage;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public void wire() {
		getInstance();
		super.wire();
		/*Recherche d'une instance UniteMesure ayant le symbole like "U" pour l'affecter
		 *à l'instance de l'equipement encours pour que l'utilisateur ne se trouve pas toujours  
		 *  oubliger de sélectionner à chaque fois l'Unité de mesure "U" qui est évidente
		 *  
		*/
		
		/////////////// Insertion/Affectation de l'Unité de mesure//////////////////////////
		final String symboleUom = "U";
		
		UniteMesure unite=null;
		
		try
		{
			unite = (UniteMesure) entityManager
			.createQuery(
					"select unite from UniteMesure unite where lower(unite.symboleUom) like :symbole")
			.setParameter("symbole",
					symboleUom.toLowerCase())
			.getSingleResult();
		}
		catch(NoResultException nre)
		{
			log.debug("L'unité de mesure concernée "+symboleUom+" n'existe pas dans la base : >>>>>> ");
		}
		
		
		if (unite == null) 
		{

			log.info(":::::::::::::::::::::::::::::::Création de l'Unité de mesure::::::::::::::::");
			
			
			unite=new UniteMesure("U","Unité");

			// /Persistance de l'objet UOM
			entityManager.persist(unite);
			
		} 
		else 
		{
			System.out.println("-----------------------L'unité de Mesure concernée existe déjà dans la base : "
											+unite.getSymboleUom());
		}
		
		////////////////Affectation de l'unite trouvée à l'instance de l'équipement
		
		getInstance().setUniteMesure(unite);
		
	}

	public boolean isWired() {
		return true;
	}

	public CaisseRamassage getInstance() 
	{
		return (CaisseRamassage)super.getInstance();
	}
	
	public CaisseRamassage getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}

	public List<InventaireClientCaisses> getListeInventairesClientCaisses() {
		return getInstance() == null ? null
				: new ArrayList<InventaireClientCaisses>(getInstance()
						.getListeInventairesClientCaisses());
	}

}
