package com.agritrace.session;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.CaisseRamassage;
import com.agritrace.entity.entrepots.Entrepot;
import com.agritrace.entity.gestionCommercial.CaissesRamassageLivraison;
import com.agritrace.entity.gestionCommercial.Livraison;

@Name("caissesRamassageLivraisonHome")
public class CaissesRamassageLivraisonHome extends EntityHome<CaissesRamassageLivraison> {

	@In(create=true)
	DomaineSession domaineSession;
	
	@In(create = true)
	CaisseRamassageHome caisseRamassageHome;
	
	@In(create = true)
	LivraisonHome livraisonHome;
	
	@In(create=true)
	EntityManager entityManager;
	
	private String caissePalette;
	
	private String entrepot;	
	
	@Logger
	Log logger;

	
	public String getCaissePalette() 
	{
		return (getInstance().getCaisseRamassage()!= null ? getInstance().getCaisseRamassage().getDesignation() : this.caissePalette);
	}

	public void setCaissePalette(String caissePalette) 
	{
		this.caissePalette = caissePalette;
		setInstanceCaissePalette();
	}

	private void setInstanceCaissePalette() 
	{
		// TODO Auto-generated method stub
		CaisseRamassage caisseRamassageInstance =null;
		
		if(!this.caissePalette.equals(""))
		{
			try
			{
				caisseRamassageInstance = (CaisseRamassage)entityManager.createQuery("select caisse from CaisseRamassage caisse where " +
												"caisse.designation =:param")
				.setParameter("param", this.caissePalette)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(caisseRamassageInstance!=null)
			{
				getInstance().setCaisseRamassage(caisseRamassageInstance);
			}
		}
	}

	public String getEntrepot() 
	{
		return (getInstance().getEntrepot()!=null ? getInstance().getEntrepot().getDenomination() : this.entrepot);
	}

	public void setEntrepot(String entrepot) {
		this.entrepot = entrepot;
		setInstanceEntrepot();
	}

	private void setInstanceEntrepot() 
	{
		Entrepot entrepot=null;
		
		try
		{
			entrepot = (Entrepot) entityManager.createQuery("select entrepot from Entrepot entrepot where " +
			"entrepot.denomination =:param1 and entrepot.domaine.libelleDomaine = #{domaineSession.domaine.libelleDomaine}")
			.setParameter("param1", this.entrepot)
			.getSingleResult();
		}
		catch(NoResultException nre)
		{
			
		}
		
		if(entrepot!=null)
		{
			getInstance().setEntrepot(entrepot);
		}
		
	}
	
	public void setCaissesRamassageLivraisonIdCaissesRamassageLivraison(Long id) {
		setId(id);
	}

	public Long getCaissesRamassageLivraisonIdCaissesRamassageLivraison() {
		return (Long) getId();
	}

	@Override
	protected CaissesRamassageLivraison createInstance() {
		CaissesRamassageLivraison caissesRamassageLivraison = new CaissesRamassageLivraison();
		return caissesRamassageLivraison;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public void wire() 
	{
		getInstance();
		CaisseRamassage caisseRamassage = caisseRamassageHome
				.getDefinedInstance();
		if (caisseRamassage != null) {
			getInstance().setCaisseRamassage(caisseRamassage);
		}
		/*
		Emplacement emplacement = emplacementHome.getDefinedInstance();
		if (emplacement != null) {
			getInstance().setEmplacement(emplacement);
		}
		*/
		Livraison livraison = livraisonHome.getDefinedInstance();
		if (livraison != null) {
			getInstance().setLivraison(livraison);
		}
	}

	public boolean isWired() {
		if (getInstance().getCaisseRamassage() == null)
			return false;
		if (getInstance().getLivraison() == null)
			return false;
		return true;
	}

	public CaissesRamassageLivraison getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}
	
	public void caissePaletteChanged(ValueChangeEvent event)
	{	
		String designation = (String)event.getNewValue();
		
		if(!designation.trim().equals(""))
		{
			setCaissePalette(designation);
			logger.info(">>>>>>>>>>>>>>>>> Caisse/Palette changed : "+designation);
		}
	}
	
	public void entrepotChanged(ValueChangeEvent event)
	{	
		String designation = (String)event.getNewValue();
		
		if(!designation.trim().equals(""))
		{
			setEntrepot(designation);
			logger.info(">>>>>>>>>>>>>>>>> Entrepôt changed : "+designation);
		}
	}

}
