package com.agritrace.session;

import java.util.ArrayList;
import java.util.List;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;

import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;
import com.agritrace.entity.gestionCommercial.Commande;
import com.agritrace.entity.gestionCommercial.LigneCommande;
import com.agritrace.entity.tiers.Fournisseur;

@Name("commandeHome")
public class CommandeHome extends EntityHome<Commande> {


	@In(create=true)
	CampagneSession campagneSession;
	
	@In
	DomaineSession domaineSession;

	@Logger
	Log logger;
	
	private String nomFournisseur;
	
	@In
	EntityManager entityManager;
	
	
	public String getNomFournisseur() 
	{
		return (getInstance().getFournisseur()!=null ? getInstance().getFournisseur().getLibelleTiers() : this.nomFournisseur);
	}

	public void setNomFournisseur(String nomFournisseur) 
	{
		this.nomFournisseur = nomFournisseur;
		setInstanceFournisseur();
	}

	
	private void setInstanceFournisseur() 
	{
		
		Fournisseur fournisseurInstance =null;
		
		if(!this.nomFournisseur.equals(""))
		{
			try
			{
				fournisseurInstance = (Fournisseur)entityManager.createQuery("select fournisseur from Fournisseur fournisseur where " +
												"fournisseur.libelleTiers =:param")
				.setParameter("param", this.nomFournisseur)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(fournisseurInstance!=null)
			{
				getInstance().setFournisseur(fournisseurInstance);
			}
		}
	}
	

	public void setCommandeIdCommande(Long id) {
		setId(id);
	}

	public Long getCommandeIdCommande() {
		return (Long) getId();
	}

	@Override
	protected Commande createInstance() {
		Commande commande = new Commande();
		return commande;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public void wire() {
		getInstance();
		
		//////////////////////L'objet campagne va être affecté implicitement
		
		//Campagne campagne = campagneHome.getDefinedInstance();
		
		Campagne campagne=campagneSession.getCampagne();
		
		if (campagne != null) {
			getInstance().setCampagne(campagne);
		}
		
		Domaine domaine= domaineSession.getDomaine();
		
		if(domaine!=null)
		{
			getInstance().setDomaine(domaine);
		}
		
	}

	public boolean isWired() {
		if (getInstance().getCampagne() == null)
			return false;
		if (getInstance().getDomaine() == null)
			return false;
		if (getInstance().getFournisseur() == null)
			return false;
		return true;
	}

	public Commande getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}

	public List<LigneCommande> getLignesCommande() 
	{
		return getInstance() == null ? null : new ArrayList<LigneCommande>(
				getInstance().getLignesCommande());
	}
	
	public void fournisseurChanged(ValueChangeEvent event)
	{
		//Fournisseur fournisseur=(Fournisseur)event.getNewValue();
		
		String nomFournisseur = (String)event.getNewValue();
		
		if(!nomFournisseur.trim().equals(""))
		{
			setNomFournisseur(nomFournisseur);
			logger.info(">>>>>>>>>>>>>>>>> Fournisseur changed : "+nomFournisseur);
		}
	}
	
	

}
