package com.agritrace.session;

import java.math.BigDecimal;

import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;

import com.agritrace.entity.production.DetailsInterventionParcelleCulturale;
import com.agritrace.entity.production.Intervention;
import com.agritrace.entity.production.ParcelleCulturale;

@Name("detailsInterventionParcelleCulturaleHome")
public class DetailsInterventionParcelleCulturaleHome extends
		EntityHome<DetailsInterventionParcelleCulturale> {

	@In(create = true)
	InterventionHome interventionHome;
	
	@In(create = true)
	ParcelleCulturaleHome parcelleCulturaleHome;

	@In
	EntityManager entityManager;
	
	private String numeroParcelleCulturale;
	
	@Logger
	Log logger;

	public String getNumeroParcelleCulturale() {
		
		return (getInstance().getParcelleCulturale()!=null ? getInstance().getParcelleCulturale().getNumeroParcelleCulturale() : numeroParcelleCulturale);
	}

	public void setNumeroParcelleCulturale(String numeroParcelleCulturale) {
		this.numeroParcelleCulturale = numeroParcelleCulturale;
		setInstanceParcelleCulturale();
	}

	public void setDetailsInterventionParcelleCulturaleIdDetailsInterventionParcelleCulturale(
			Long id) {
		setId(id);
	}

	public Long getDetailsInterventionParcelleCulturaleIdDetailsInterventionParcelleCulturale() {
		return (Long) getId();
	}

	@Override
	protected DetailsInterventionParcelleCulturale createInstance() {
		DetailsInterventionParcelleCulturale detailsInterventionParcelleCulturale = new DetailsInterventionParcelleCulturale();
		return detailsInterventionParcelleCulturale;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public void wire() 
	{
		
		getInstance();
	
		Intervention intervention = interventionHome.getDefinedInstance();
		if (intervention != null) {
			getInstance().setIntervention(intervention);
		}
		
	}

	public boolean isWired() {
		if (getInstance().getIntervention() == null)
			return false;
		if (getInstance().getParcelleCulturale() == null)
			return false;
		return true;
	}

	public DetailsInterventionParcelleCulturale getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}

	public void setInstanceParcelleCulturale()
	{
		ParcelleCulturale parcelleCulturaleInstance =null;
		
		if(!this.numeroParcelleCulturale.trim().equals(""))
		{
			try
			{
				parcelleCulturaleInstance = (ParcelleCulturale) entityManager.createQuery("select parcelleCulturale from ParcelleCulturale parcelleCulturale where " +
												"parcelleCulturale.numeroParcelleCulturale =:numero")
				.setParameter("numero", this.numeroParcelleCulturale)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(parcelleCulturaleInstance!=null)
			{
				getInstance().setParcelleCulturale(parcelleCulturaleInstance);
			}
		}
		
	}
	
	public void parcelleCulturaleChanged(ValueChangeEvent event)
	{
		String parcelleCulturaleSelected=(String)event.getNewValue();
		
		if(!parcelleCulturaleSelected.trim().equals(""))
		{
			setNumeroParcelleCulturale(parcelleCulturaleSelected);
			logger.info(">>>>>>>>>>>>>>>>> Parcelle culturale changed : "+parcelleCulturaleSelected);
		}
		else
		{
			setNumeroParcelleCulturale(null);
		}
	}
	
	
	public void nbreBillonsChanged(ValueChangeEvent event)
	{
		if(getInstance().getParcelleCulturale()==null)
		{
			FacesContext context = getFacesContext();
			FacesMessage message = new FacesMessage(FacesMessage.SEVERITY_WARN, "Parcelle culturale requise", "Vous devez d'abord sélectionner une parcelle culturale");
			context.addMessage(null, message);
		}
		else
		{
			//Donnnées
			int nombreBillonTravaille; //==> nombre de billons travaillé 
			int nombreTotalBillons;  //==> nombre total de billon de la parcelle 
			double superficieTotal;  //==> superficie de la parcelle culturale
			
			//A calculer
			double superficieTravaillee;
			
			try
			{
				
				//Affectation de données
				nombreBillonTravaille = (Integer)event.getNewValue();
				nombreTotalBillons = getInstance().getParcelleCulturale().getNombreBillons();
				superficieTotal = getInstance().getParcelleCulturale().getParcelle().getSurface();
				
				//formule de calcule de la superficie travaillé
				
				superficieTravaillee = (nombreBillonTravaille * superficieTotal) / nombreTotalBillons ;
				logger.info("nombreBillonTravaille : "+nombreBillonTravaille+"\n"+" nombreTotalBillons : "+nombreTotalBillons+"\n"+ " superficieTotal :"+superficieTotal);
				logger.info("superfieTravaillee : "+superficieTravaillee+" Ha");
				
				getInstance().setSuperficieTravailleeHa(superficieTravaillee);

			}catch(Exception nfe)
			{
				
			}
		}
		
	}
	

}
