package com.agritrace.session;

import java.util.ArrayList;
import java.util.List;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;

import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;
import com.agritrace.entity.domaine.Domaine;
import com.agritrace.entity.userRoles.Users;

@Name("domaineSession")
@Scope(value=ScopeType.SESSION)
public class DomaineSession extends EntityHome<Users>
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	@In
	private EntityManager entityManager;
	
	private List<String> listeDomaine = new ArrayList<String>();
	
	private String domaineCourant="";
	
	private Domaine domaine=null;
	
	@Logger
	Log logger;
	
	
	public Domaine getDomaine() {
		return domaine;
	}

	public void setDomaine(Domaine domaine) {
		this.domaine = domaine;
	}

	public String getDomaineCourant() {
		return domaineCourant;
	}

	public void setDomaineCourant(String domaineCourant) {
		this.domaineCourant = domaineCourant;
	}
	
	public void domaineChanged(ValueChangeEvent event)  
	{
		logger.info("******************************** DomaineChanged () Déclenchée !!!!!!!!!!!!!!!!!!");
		
		domaineCourant =  (String)event.getNewValue();
		
		if(!domaineCourant.trim().equals(""))
		{
			try
			{
				domaine=(Domaine)entityManager.createQuery("select domaine from Domaine domaine where domaine.libelleDomaine=:domaine")
				.setParameter("domaine", domaineCourant).getSingleResult();
				logger.info("************ L'objet domaine sélectionné est : >>>>>>>>>>>>>>>>>>>>>>>>>>>>>"+domaine.getLibelleDomaine());
			}
			catch(Exception ex)
			{
				ex.getStackTrace();
				domaine=null;
				logger.info("Une exception a été déclenché durant le chargement du domaine sélectionnée !!!!!!!!!!!!!!");
			}
			
		}
		else
		{
			this.domaine=null;
			this.domaineCourant="";
			logger.info("Aucun domaine n'a été sélectionné !!!!!!!!!!!!!!!!!!!!!!!");
		}
	}
	
	@SuppressWarnings("unchecked")
	public void wire() 
	{
		listeDomaine =new ArrayList<String>();
		
		/// Le super utilisateur et l'administrateur peuvent accéder à tous les domaines
		if(getInstance().getUsername().equals("ardassdev") || getInstance().getLibelleRole().equals("Administrateur"))
		{
			listeDomaine.addAll(entityManager.createQuery("select domaine.libelleDomaine from Domaine domaine order by domaine.libelleDomaine asc")
			.getResultList());

		}
		else
		{
			/// Chaque utilisateur accède aux domaines qui lui ont été affecté	
			
			listeDomaine.addAll(entityManager.createQuery("select userAffectationDomaine.domaine.libelleDomaine from UserAffectationDomaine userAffectationDomaine" +
			" where userAffectationDomaine.user.username =:username order by userAffectationDomaine.domaine.libelleDomaine asc")
			.setParameter("username", getInstance().getUsername())
			.getResultList());
		}
		logger.info("************************************************************* [DomaineSession : wire() méthode ] : La taille de La DomaineListe :"+listeDomaine.size());
	}

	public List<String> getListeDomaine() {
		return listeDomaine;
	}

	public void setListeDomaine(List<String> listeDomaine) {
		this.listeDomaine = listeDomaine;
	}

}
