package com.agritrace.session;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.Equipement;
import com.agritrace.entity.unitesMesure.*;
import com.agritrace.entity.articles.MarqueEquipement;
import com.agritrace.entity.articles.TypeEquipement;

@Name("equipementHome")
public class EquipementHome<E> extends ArticleHome<Equipement> {

	@In(create = true)
	MarqueEquipementHome marqueEquipementHome;
	@In(create = true)
	TypeEquipementHome typeEquipementHome;
	
	@Logger
	Log log;
	
	@In
	EntityManager entityManager;
	
	public void setEquipementIdArticle(Long id) {
		setId(id);
	}

	public Long getEquipementIdArticle() {
		return (Long) getId();
	}

	@Override
	protected Equipement createInstance() {
		Equipement equipement = new Equipement();
		return equipement;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public Equipement getInstance() {
		return (Equipement)super.getInstance();
	}
	
	public void wire() {
		getInstance();
		MarqueEquipement marqueEquipement = marqueEquipementHome
				.getDefinedInstance();
		if (marqueEquipement != null) {
			getInstance().setMarqueEquipement(marqueEquipement);
		}
		TypeEquipement typeEquipement = typeEquipementHome.getDefinedInstance();
		if (typeEquipement != null) {
			getInstance().setTypeEquipement(typeEquipement);
		}
		
		/*Recherche d'une instance UniteMesure ayant le symbole like "U" pour l'affecter
		 *à l'instance de l'equipement encours pour que l'utilisateur ne se trouve pas toujours  
		 *  oubliger de sélectionner à chaque fois l'Unité de mesure "U" qui est évidente
		 *  
		*/
		
		/////////////// Insertion/Affectation de l'Unité de mesure//////////////////////////
		final String symboleUom = "U";
		
		UniteMesure unite=null;
		
		try
		{
			unite = (UniteMesure) entityManager
			.createQuery(
					"select unite from UniteMesure unite where lower(unite.symboleUom) like :symbole")
			.setParameter("symbole",
					symboleUom.toLowerCase())
			.getSingleResult();
		}
		catch(NoResultException nre)
		{
			log.debug("L'unité de mesure concernée "+symboleUom+" n'existe pas dans la base : >>>>>> ");
		}
		
		
		if (unite == null) 
		{

			log.info(":::::::::::::::::::::::::::::::Création de l'Unité de mesure::::::::::::::::");
			
			
			unite=new UniteMesure("U","Unité");

			// /Persistance de l'objet UOM
			entityManager.persist(unite);
			
		} 
		else 
		{
			System.out.println("-----------------------L'unité de Mesure concernée existe déjà dans la base : "
											+unite.getSymboleUom());
		}
		
		////////////////Affectation de l'unite trouvée à l'instance de l'équipement
		
		getInstance().setUniteMesure(unite);
		
		System.out.println("-----------------------Unité de Mesure affectée avec succès");
		
		
	}

	public boolean isWired() {
		if(getInstance().getTypeEquipement()==null || getInstance().getMarqueEquipement()==null)
		{
			return false;
		}
		return true;
	}

	public Equipement getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}
	
	public void typeChanged(ValueChangeEvent event)
	{
		TypeEquipement typeEquipement = (TypeEquipement)event.getNewValue();
		
		if(typeEquipement!=null)
		{
			System.out.println("****************** Un nouveau type a été choisi : "+typeEquipement.getTypeEquipement());
			getInstance().setTypeEquipement(typeEquipement);
		}
	}
	
	public void marqueChanged(ValueChangeEvent event)
	{
		MarqueEquipement marqueEquipement = (MarqueEquipement)event.getNewValue();
		
		if(marqueEquipement!=null)
		{
			System.out.println("****************** Une nouvelle marque a été choisi : "+marqueEquipement.getMarqueEquipement());
			getInstance().setMarqueEquipement(marqueEquipement);
		}
	}

}
