package com.agritrace.session;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;

import com.agritrace.entity.convention.Campagne;
import com.agritrace.entity.domaine.Domaine;
import com.agritrace.entity.production.CiblesTraitementPhyto;
import com.agritrace.entity.production.DetailsInterventionCategorieMo;
import com.agritrace.entity.production.DetailsInterventionMateriel;
import com.agritrace.entity.production.DetailsInterventionMo;
import com.agritrace.entity.production.DetailsInterventionOutillage;
import com.agritrace.entity.production.DetailsInterventionParcelleCulturale;
import com.agritrace.entity.production.DetailsInterventionProduits;
import com.agritrace.entity.production.Intervention;
import com.agritrace.entity.production.Operation;
import com.agritrace.entity.production.OrdreIntervention;

@Name("interventionHome")
public class InterventionHome<E> extends EntityHome<Intervention> {

	@In(create = true)
	CampagneHome campagneHome;
	
	@In(create = true)
	OrdreInterventionHome ordreInterventionHome;
	
	@In(create = true)
	EntityManager entityManager;
	
	@In(create=true)
	CampagneSession campagneSession;
	
	@In(create=true)
	DomaineSession domaineSession;
	
	private String numeroOrdre="";
	
	private String libelleOperation="";
	
	@Logger
	Log logger;


	public void setLibelleOperation(String libelleOperation) 
	{
		this.libelleOperation = libelleOperation;
		setInstanceOperation();
	}

	public String getLibelleOperation() 
	{
		return (getInstance().getOperation()!=null ? getInstance().getOperation().getOperation() : this.libelleOperation);
	}
	
	public void setInstanceOperation()
	{
		Operation operationInstance =null;
		
		if(!this.libelleOperation.equals(""))
		{
			try
			{
				operationInstance = (Operation)entityManager.createQuery("select operation from Operation operation where " +
												"operation.operation =:param")
				.setParameter("param", this.libelleOperation)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(operationInstance!=null)
			{
				getInstance().setOperation(operationInstance);
			}
		}
		
	}
	
	public String getNumeroOrdre() 
	{
		return (getInstance().getOrdreIntervention()!=null ? getInstance().getOrdreIntervention().getNumeroOrdreIntervention() : this.numeroOrdre);
	}
	
	public void setNumeroOrdre(String numeroOrdre) 
	{
		this.numeroOrdre = numeroOrdre;
		setInstanceOrdreIntervention();
	}
	
	public void setInstanceOrdreIntervention()
	{
		OrdreIntervention ordreInterventionInstance =null;
		
		if(!this.numeroOrdre.equals(""))
		{
			try
			{
				ordreInterventionInstance = (OrdreIntervention)entityManager.createQuery("select ordreIntervention from OrdreIntervention ordreIntervention where " +
												"ordreIntervention.numeroOrdreIntervention =:numero")
				.setParameter("numero", this.numeroOrdre)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(ordreInterventionInstance!=null)
			{
				getInstance().setOrdreIntervention(ordreInterventionInstance);
			}
		}
		
	}
	
	public void setInterventionIdIntervention(Long id) {
		setId(id);
	}

	public Long getInterventionIdIntervention() {
		return (Long) getId();
	}

	@Override
	protected Intervention createInstance() {
		Intervention intervention = new Intervention();
		return intervention;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}
	

	public void wire() 
	{
		getInstance();
		
		///////////////////////L'objet campagne va être affecté implicitement
		
		//Campagne campagne = campagneHome.getDefinedInstance();
		
		Campagne campagne=campagneSession.getCampagne();
		
		if (campagne != null) 
		{
			getInstance().setCampagne(campagne);
		}
		
        Domaine domaine=domaineSession.getDomaine();
		
		if (domaine != null) 
		{
			getInstance().setDomaine(domaine);
		}
		
		OrdreIntervention ordreIntervention = ordreInterventionHome.getDefinedInstance();
		
		if(ordreIntervention!=null)
		{
			getInstance().setOrdreIntervention(ordreIntervention);
		}
	}
	
	@Override
	public String remove() 
	{
		String result = super.remove();

		if(getInstance().getOrdreIntervention()!=null)
		{
			Long idOrdreIntervention = getInstance().getOrdreIntervention().getIdOrdreIntervention();
			
			entityManager.createQuery("update OrdreIntervention ordre set ordre.ordreExecute = false where " +
					"ordre.idOrdreIntervention = :id")
					.setParameter("id", idOrdreIntervention)
					.executeUpdate();
		}
		
		return result;
	}

	@Override
	public String persist() {
		
		String result =  super.persist();
		
		
		System.out.println("I'm inside persist méthode !!!!!!!!!!!!!!!!!!");
		
		if(getInstance().getOrdreIntervention()!=null)
		{
			Long idOrdreIntervention = getInstance().getOrdreIntervention().getIdOrdreIntervention();
			
			entityManager.createQuery("update OrdreIntervention ordre set ordre.ordreExecute = true where " +
					"ordre.idOrdreIntervention = :id")
					.setParameter("id", idOrdreIntervention)
					.executeUpdate();
			
			System.out.println("Ordre not null");
			
		}
				
		return result;
		
	}
	
	@Override
	public String update() 
	{
		String result = super.update();

		if(getInstance().getOrdreIntervention()!=null)
		{
			Long idOrdreIntervention = getInstance().getOrdreIntervention().getIdOrdreIntervention();
			
			entityManager.createQuery("update OrdreIntervention ordre set ordre.ordreExecute = true where " +
					"ordre.idOrdreIntervention = :id")
					.setParameter("id", idOrdreIntervention)
					.executeUpdate();
		}
		
		return result;
	}
	
	public boolean isWired() {
		
		if (getInstance().getCampagne() == null || getInstance().getOperation() == null
												|| getInstance().getDomaine() == null)
			return false;
		return true;
	}

	public Intervention getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}

	
	public List<DetailsInterventionParcelleCulturale> getDetailsInterventionParcelleCulturales() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionParcelleCulturale>(
						getInstance()
								.getDetailsInterventionParcelleCulturales());
	}
	
	public List<DetailsInterventionOutillage> getDetailsInterventioOutillage() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionOutillage>(getInstance()
						.getDetailsInterventioOutillage());
	}

	public List<DetailsInterventionMateriel> getDetailsInterventionMateriel() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionMateriel>(getInstance()
						.getDetailsInterventionMateriel());
	}

	public List<DetailsInterventionMo> getDetailsInterventionMo() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionMo>(getInstance()
						.getDetailsInterventionMo());
	}

	public List<DetailsInterventionProduits> getDetailsInterventionProduits() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionProduits>(getInstance()
						.getDetailsInterventionProduits());
	}
	
	public List<DetailsInterventionCategorieMo> getDetailsInterventionCategorieMo() {
		return getInstance() == null ? null
				: new ArrayList<DetailsInterventionCategorieMo>(getInstance()
						.getDetailsInterventionCategorieMo());
	}
	
	public List<CiblesTraitementPhyto> getCiblesTraitementPhytos() {
		return getInstance() == null ? null
				: new ArrayList<CiblesTraitementPhyto>(getInstance()
						.getCiblesTraitementPhytos());
	}
	
	public void operationChanged(ValueChangeEvent event)
	{
		String libelleOperation = (String)event.getNewValue();
			
		if(!libelleOperation.trim().equals(""))
		{
			setLibelleOperation(libelleOperation);
			logger.info(">>>>>>>>>>>>>>>>> Opération changed : "+libelleOperation);
		}
		else
		{
			setLibelleOperation("");
		}
		
	}
	
	
	public void ordreInterventionChanged(ValueChangeEvent event)
	{
		String ordrInterventionOld=(String)event.getOldValue();
		
		String ordrInterventionNew=(String)event.getNewValue();
		
		///////////////////////////////////////// The older
		if(!ordrInterventionOld.trim().equals(""))
		{
			logger.info(">>>>>>>>>>>>>>>>> Ordre Intervention Old : "+ordrInterventionOld);
			
			entityManager.createQuery("update OrdreIntervention ordre set ordre.ordreExecute = false where " +
					"ordre.numeroOrdreIntervention = :numero")
					.setParameter("numero", ordrInterventionOld)
					.executeUpdate();
		}
		
		/////////////////////////////////////// The New Value
		if(!ordrInterventionNew.trim().equals(""))
		{
			setNumeroOrdre(ordrInterventionNew);
			logger.info(">>>>>>>>>>>>>>>>> Ordre Intervention New : "+ordrInterventionNew);
		}
		else
		{
			setNumeroOrdre("");
		}
		
	}

	public void heureDebutChanged(ValueChangeEvent event)
	{
		Date dateChoosed = (Date)event.getNewValue();
	
		if(dateChoosed!=null)
		{
			logger.info("La date est valide :) :) :) :) :) :) :) :)");
			getInstance().setHeureDebutIntervention(dateChoosed);
			getInstance().setHeureFinIntervention(dateChoosed);
			logger.info("Toutes les dates ont été mise à jour :) :) :) :) :) :) :) :)");
		}
	
	}

}
