package com.agritrace.session;

import java.util.ArrayList;
import java.util.List;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityHome;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.PorteGreffe;
import com.agritrace.entity.articles.Variete;
import com.agritrace.entity.domaine.Parcelle;
import com.agritrace.entity.production.CyclePlanningProduction;
import com.agritrace.entity.production.EstimationProductionSemaine;
import com.agritrace.entity.production.ParcelleCulturale;

@Name("parcelleCulturaleHome")
public class ParcelleCulturaleHome extends EntityHome<ParcelleCulturale> {

	@In(create = true)
	CyclePlanningProductionHome cyclePlanningProductionHome;
	
	@In(create=true)
	DomaineSession domaineSession;
	
	@In(create = true)
	ParcelleHome parcelleHome;

	@In
	EntityManager entityManager;
	
	private String numeroParcelle;
	
	@In(create=true)
	VarieteHome varieteHome;
	
	@In(create=true)
	PorteGreffeHome porteGreffeHome;
	
	
	private String variete;
	
	private String porteGreffe;
	
	@Logger
	Log logger;
	
	
	
	public String getNumeroParcelle() 
	{
		return (getInstance().getParcelle()!=null ? getInstance().getParcelle().getNumeroParcelle() : numeroParcelle);
	}

	public void setNumeroParcelle(String numeroParcelle) {
		this.numeroParcelle = numeroParcelle;
		setInstanceParcelle();
	}

	private void setInstanceParcelle() 
	{
		
		Parcelle parcelleInstance =null;
		
		if(!this.numeroParcelle.trim().equals(""))
		{
			try
			{
				parcelleInstance = (Parcelle) entityManager.createQuery("select parcelle from Parcelle parcelle where " +
												"parcelle.numeroParcelle =:numero and " +
												"parcelle.domaine.libelleDomaine = #{domaineSession.domaine.libelleDomaine}")
				.setParameter("numero", this.numeroParcelle)
				.getSingleResult();
			}
			catch(NoResultException nre)
			{
			}
			
			if(numeroParcelle!=null)
			{
				getInstance().setParcelle(parcelleInstance);
			}
		}
		
		
	}

	
	public String getPorteGreffe() 
	{
		return (getInstance().getPorteGreffe()!=null ? getInstance().getPorteGreffe().getDesignation() : porteGreffe);
	}

	public void setPorteGreffe(String porteGreffe) {
		this.porteGreffe = porteGreffe;
		setInstancePorteGreffe();
	}

	private void setInstancePorteGreffe() 
	{
		// TODO Auto-generated method stub
		
		PorteGreffe porteGreffeInstance = null;
		
		if(!porteGreffe.trim().equals(""))
		{
			porteGreffeInstance = (PorteGreffe) entityManager.createQuery("select porteGreffe from PorteGreffe porteGreffe where " +
					"porteGreffe.designation =:param1 and porteGreffe.variete.designation =:param2 ")
					.setParameter("param1", this.porteGreffe)
					.setParameter("param2", getInstance().getVariete().getDesignation())
					.getSingleResult();
		}
		
		if(porteGreffeInstance!=null)
		{
			getInstance().setPorteGreffe(porteGreffeInstance);
		}
		
	}

	public String getVariete() 
	{
		return (getInstance().getVariete()!=null ? getInstance().getVariete().getDesignation() : variete);
	}

	public void setVariete(String variete) {
		this.variete = variete;
		setInstanceVariete();
	}

	private void setInstanceVariete() 
	{
		Variete varieteInstance = null;
		
		if(!variete.trim().equals(""))
		{
			varieteInstance = (Variete) entityManager.createQuery("select variete from Variete variete where " +
					"variete.designation =:param")
					.setParameter("param", this.variete)
					.getSingleResult();
		}
		
		if(varieteInstance!=null)
		{
			getInstance().setVariete(varieteInstance);
		}
	}

	
	@SuppressWarnings("unchecked")
	public List<String> getListePortesGreffeByVariete()
	{
		if(variete!=null)
		{
			return entityManager.createQuery("select porteGreffe.designation from PorteGreffe porteGreffe " +
					"where porteGreffe.variete.designation = :param " +
					"order by porteGreffe.designation asc")
					.setParameter("param", this.variete)
					.getResultList();
		}
		else
		{
			return new ArrayList<String>();
		}
		
	}
	
	public void setParcelleCulturaleIdParcelleCulturale(Long id) {
		setId(id);
	}

	public Long getParcelleCulturaleIdParcelleCulturale() {
		return (Long) getId();
	}

	@Override
	protected ParcelleCulturale createInstance() {
		ParcelleCulturale parcelleCulturale = new ParcelleCulturale();
		return parcelleCulturale;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}

	public void wire() {
		getInstance();
		
		CyclePlanningProduction cyclePlanningProduction = cyclePlanningProductionHome
				.getDefinedInstance();
		if (cyclePlanningProduction != null) {
			getInstance().setCyclePlanningProduction(cyclePlanningProduction);
		}
		
		Parcelle parcelle = parcelleHome.getDefinedInstance();
		if (parcelle != null) {
			getInstance().setParcelle(parcelle);
		}
		
		Variete variete = varieteHome.getDefinedInstance();
		if (variete != null) {
			getInstance().setVariete(variete);
		}
		
		PorteGreffe porteGreffe = porteGreffeHome.getDefinedInstance();
		if(porteGreffe!=null)
		{
			getInstance().setPorteGreffe(porteGreffe);
		}
	}

	public boolean isWired() {
		if (getInstance().getCyclePlanningProduction() == null)
			return false;
		if (getInstance().getParcelle() == null)
			return false;
		if(getInstance().getVariete()==null)
			return false;
		return true;
	}

	public ParcelleCulturale getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}
	

	public List<EstimationProductionSemaine> getListeEstimationProductionParSemaine() {
		return getInstance() == null ? null
				: new ArrayList<EstimationProductionSemaine>(getInstance()
						.getListeEstimationProductionParSemaine());
	}

	
	public void parcelleChanged(ValueChangeEvent event)
	{
		System.out.println("******************** calling parcelleSelected() méthode ");
		
		String numeroParcelle = (String)event.getNewValue();

		setNumeroParcelle(numeroParcelle);
		
		logger.info("ParcelleCulturaleHome", "Parcelle changed : "+numeroParcelle);		
	}
	
	public void varieteChanged(ValueChangeEvent event)
	{
		String variete = (String)event.getNewValue();

		setVariete(variete);
		
		logger.info("ParcelleCulturaleHome", "Variété changed : "+variete);
	}
	
	public void porteGreffeChanged(ValueChangeEvent event)
	{
		String porteGreffe = (String)event.getNewValue();

		setPorteGreffe(porteGreffe);
		
		logger.info("ParcelleCulturaleHome", "Porte-greffe changed : "+porteGreffe);
	}
	
	public void nombreBillonsChanged(ValueChangeEvent event)
	{
		try
		{
			int nombreBillons = (Integer)event.getNewValue();  /// Plants par m²
			getInstance().setNombreBillons(nombreBillons);
		}catch(Exception ex)
		{
			ex.printStackTrace();
		}
		
	}
	
	public void plantsParBillonChanged(ValueChangeEvent event)
	{
		//donnéess
		int nombreBillon = 0;
		int nombrePlantsParBillon = 0;
		double surfaceParcelleC; 
		
		//à calculer
		int densitePlantation;  /// Plants par m²
		
		///Récupération des valeurs
		
		nombreBillon = getInstance().getNombreBillons();
		surfaceParcelleC = getInstance().getParcelle().getSurface();
		
		try
		{
			nombrePlantsParBillon = (Integer)event.getNewValue();  /// Plants par m²
			getInstance().setNombrePlantsParBillon(nombrePlantsParBillon);
		}catch(Exception ex)
		{
			ex.printStackTrace();
		}
		
		if(nombreBillon > 0 && nombrePlantsParBillon >0)
		{
			densitePlantation = (int) ((int)(nombreBillon * nombrePlantsParBillon) /  (surfaceParcelleC * 10000));	
			getInstance().setDensitePlantation(densitePlantation);
		}
		else
		{
			getInstance().setDensitePlantation(0);
		}
	}
}
