package com.agritrace.session;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityQuery;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.Article;
import com.agritrace.entity.articles.Inventaire;
import com.agritrace.entity.articles.StockParEntrepot;
import com.agritrace.entity.entrepots.Entrepot;

@Name("stockParEntrepotList")
public class StockParEntrepotList extends EntityQuery<Entrepot> {

	@In(create=true)
	EntityManager entityManager;
	
	@In(create=true)
	CampagneSession campagneSession;
	
	@In(create=true)
	DomaineSession domaineSession;
	
	@In(create=true)
	InventaireList inventaireList;
	
	/****** Mouvements d'entrée ****/
	@In(create=true)
	LigneReceptionList ligneReceptionList;
	
	@In(create=true)
	MouvementInterEntrepotsList mouvementInterEntrepotsListEntree;
	
	private Article article;
	
	
	
	
	/*********Mouvements de sorties *****/
	@In(create=true)
	LigneRetourCaissesList ligneRetourCaissesList;
	
	@In(create=true)
	LigneRetourFournisseurList ligneRetourFournisseurList;
	
	@In(create=true)
	DetailsInterventionProduitsList detailsInterventionProduitsList;
	
	@In(create=true)
	DetailsProduitsMaintenanceList detailsProduitsMaintenanceList;
	
	@In(create=true)
	MouvementInterEntrepotsList mouvementInterEntrepotsListSortie;
	
	
	@Logger
	Log logger;
	
	private String libelleArticle="";
	
	private Date date=new Date();
	
	public Date getDate() {
		return date;
	}

	public void setDate(Date date) {
		this.date = date;
	}

	private static final String EJBQL = "select entrepot from Entrepot entrepot";

	
	private static final String[] RESTRICTIONS = 
	{ 
		"entrepot.domaine.libelleDomaine = #{domaineSession.domaine.libelleDomaine}",
	};

	public String getLibelleArticle() 
	{
		return this.libelleArticle;
	}

	public void setLibelleArticle(String libelleArticle) 
	{
		this.libelleArticle = libelleArticle;
	}

	private Article getInstanceArticle() 
	{
		
		Article articleInstance =null;
		
		if(!this.libelleArticle.equals(""))
		{
			try
			{
				articleInstance = (Article)entityManager.createQuery("select article from Article article where " +
												"article.designation =:param")
				.setParameter("param", this.libelleArticle)
				.getSingleResult();
				
				return articleInstance;
			}
			catch(NoResultException nre)
			{
				return null;
			}
		}
		
		return articleInstance;
	}
	

	
	public StockParEntrepotList() {
		setEjbql(EJBQL);
		setRestrictionExpressionStrings(Arrays.asList(RESTRICTIONS));
		//setMaxResults(13);
	}
	
	public List<StockParEntrepot> getStockParEntrepot()
	{
		List<StockParEntrepot> situationStockParEntrepot = null;
		
		
		if(this.getResultCount()!=0)
		for(Entrepot  entrepot : this.getResultList())
		{
			/*
			 * Création d'un objet StockParEntrepot pour chaque entrepot du domaine                                                                                                                                                                                                                       
			 */
			
			StockParEntrepot stock = new StockParEntrepot();
			stock.setEntrepot(entrepot);
		    //Setter l'objet entrepot à chaque objet de notre collection finale
			
			logger.info("Entrepôt :"+entrepot.getDenomination());
			
			logger.info("Starting calculating product quantities !!");
			
			List<Inventaire> listeDerniersInventaire = (List<Inventaire>)entityManager.createQuery("select inventaire from Inventaire inventaire where " +
					" inventaire.campagne.campagne = #{campagneSession.campagne.campagne} and " +
					" inventaire.domaine.libelleDomaine = #{domaineSession.domaine.libelleDomaine} and " +
					" inventaire.dateInventaire < #{stockParEntrepotList.dateInventaire}" +"")
					.getResultList();
			
			
		}
		
		/*
		 * Maintenant on va essayer de calculer pour chaque entrepôt 
		 */
		/////////////////////////////////========================>
		
		return situationStockParEntrepot;
	}
	
}
