package com.agritrace.session;

import java.util.ArrayList;
import java.util.List;

import javax.faces.event.ValueChangeEvent;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Logger;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.log.Log;

import com.agritrace.entity.articles.PorteGreffe;
import com.agritrace.entity.articles.TypeCulture;
import com.agritrace.entity.articles.Variete;
import com.agritrace.entity.unitesMesure.UniteMesure;

@Name("varieteHome")
public class VarieteHome extends ArticleHome<Variete> {

	@In(create = true)
	TypeCultureHome typeCultureHome;
	
	@Logger
	Log logger;
	
	@In
	EntityManager entityManager;
	
	private String culture;
	
	private String typeCulture;
	
	
	public String getCulture() 
	{
		return (getInstance().getTypeCulture()!=null ? getInstance().getTypeCulture().getCulture().getDesignationCulture() : this.culture);
	}

	public void setCulture(String culture) 
	{
		this.culture = culture;
		
		//Je garde la valeur de la culture choisi dans la mémoire pour les prochaines requêtes sur l'objet encours
		
		getInstance().setCulture(culture);
		
		getInstance().setTypeCulture(null);
		
		typeCulture="";
	}
	
	@SuppressWarnings("unchecked")
	public List<String> getListeTypesCulturesByCulture()
	{
		logger.info("La culture choisi est :"+getInstance().getCulture());
		
		List<String> listeTypeCultures = new ArrayList<String>(); 
		
		if(getInstance().getCulture()!=null)
		{
			
			listeTypeCultures.addAll(entityManager.createQuery("select typeCulture.typeCulture from TypeCulture typeCulture " +
					"where typeCulture.culture.designationCulture = :culture " +
			"order by typeCulture.typeCulture asc")
			.setParameter("culture", getInstance().getCulture())
			.getResultList());
			
			logger.info("ResultCount TypeCultureList : "+listeTypeCultures.size());
			return listeTypeCultures;
		}
		else
		{
			return new ArrayList<String>();
		}
		
	}
	

	public String getTypeCulture() 
	{
		return (getInstance().getTypeCulture()!=null ? getInstance().getTypeCulture().getTypeCulture() : this.typeCulture);
	}

	public void setTypeCulture(String typeCulture) {
		this.typeCulture = typeCulture;
		setTypeCultureInstance();
	}

	private void setTypeCultureInstance() 
	{
		TypeCulture typeCultureInstance = null;
		
		if(!typeCulture.trim().equals(""))
		{
			typeCultureInstance = (TypeCulture) entityManager.createQuery("select typeCulture from TypeCulture typeCulture where " +
					"typeCulture.typeCulture =:param")
					.setParameter("param", this.typeCulture)
					.getSingleResult();
		}
		
		if(typeCultureInstance!=null)
		{
			getInstance().setTypeCulture(typeCultureInstance);
		}
	}

	public void setVarieteIdArticle(Long id) {
		setId(id);
	}

	public Long getVarieteIdArticle() {
		return (Long) getId();
	}

	@Override
	protected Variete createInstance() {
		Variete variete = new Variete();
		return variete;
	}

	public void load() {
		if (isIdDefined()) {
			wire();
		}
	}
	
	public Variete getInstance() 
	{
		return (Variete)super.getInstance();
	}

	public void wire() {
		getInstance();
		TypeCulture typeCulture = typeCultureHome.getDefinedInstance();
		if (typeCulture != null) {
			getInstance().setTypeCulture(typeCulture);
		}
	}

	public boolean isWired() {
		if(getInstance().getTypeCulture() == null)
			return false;
		return true;
	}
	
	

	@Override
	public String persist() 
	{
		
		/*Recherche d'une instance UniteMesure ayant le symbole like "U" pour l'affecter
		 *à l'instance de l'equipement encours pour que l'utilisateur ne se trouve pas toujours  
		 *  oubliger de sélectionner à chaque fois l'Unité de mesure "U" qui est évidente
		 *  
		*/
		
		/////////////// Insertion/Affectation de l'Unité de mesure//////////////////////////
		final String symboleUom = "T";
		
		UniteMesure unite=null;
		
		try
		{
			unite = (UniteMesure) entityManager
			.createQuery(
					"select unite from UniteMesure unite where lower(unite.symboleUom) like :symbole")
			.setParameter("symbole",
					symboleUom.toLowerCase())
			.getSingleResult();
		}
		catch(NoResultException nre)
		{
			logger.debug("L'unité de mesure concernée "+symboleUom+" n'existe pas dans la base : >>>>>> ");
		}
		
		
		if (unite == null) 
		{

			logger.info(":::::::::::::::::::::::::::::::Création de l'Unité de mesure::::::::::::::::");
			
			
			unite=new UniteMesure("T","Tonne");

			// /Persistance de l'objet UOM
			entityManager.persist(unite);
			
		} 
		else 
		{
			System.out.println("-----------------------L'unité de Mesure concernée existe déjà dans la base : "
											+unite.getSymboleUom());
		}
		
		////////////////Affectation de l'unite trouvée à l'instance de l'équipement
		
		getInstance().setUniteMesure(unite);
		
		return super.persist();
	}

	public Variete getDefinedInstance() {
		return isIdDefined() ? getInstance() : null;
	}

	public void cultureChanged(ValueChangeEvent event)
	{
		String culture = (String)event.getNewValue();
		
		logger.info("*********** Culture changed : "+culture);
		
		setCulture(culture);
		
	}
	
	public void typeCultureChanged(ValueChangeEvent event)
	{
		String typeCulture = (String)event.getNewValue();
		
		logger.info("*********** Type culture changed : "+typeCulture);
		
		setTypeCulture(typeCulture);
	}
	
	public List<PorteGreffe> getListePortesGreffe() {
		return getInstance() == null ? null : new ArrayList<PorteGreffe>(
				getInstance().getListePortesGreffe());
	}
	
}
