package com.agritrace.session;

import java.util.Arrays;
import java.util.List;

import javax.persistence.EntityManager;

import org.jboss.seam.annotations.Factory;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.framework.EntityQuery;

import com.agritrace.entity.articles.Variete;

@Name("varieteList")
public class VarieteList extends EntityQuery<Variete> {

	@In
	EntityManager entityManager;
	
	@In(create=true)
	CyclePlanningProductionHome cyclePlanningProductionHome;
	
	private static final String EJBQL = "select variete from Variete variete";

	private static final String[] RESTRICTIONS = {
		
		"lower(variete.designation) like lower(concat(#{varieteList.variete.designation},'%'))", 
	};

	private Variete variete = new Variete();

	public VarieteList() 
	{
		setEjbql(EJBQL);
		setRestrictionExpressionStrings(Arrays.asList(RESTRICTIONS));
		setMaxResults(13);
	}

	public Variete getVariete() {
		return variete;
	}
	
	@SuppressWarnings("unchecked")
	@Factory("listeDesVarietes")
	public List<String> getListeVarietes()
	{
		//Pour faire un filtre sur la liste des variétés et ne pas que celles définit dans la ligne de convention concerné
		if(cyclePlanningProductionHome.isIdDefined())
		{
			return entityManager.createQuery("select variete.designation from Variete variete " +
					"where variete.typeCulture.typeCulture = :typeCulture " +
					"order by variete.designation asc")
					.setParameter("typeCulture", cyclePlanningProductionHome.getInstance().getPlanningProduction().getLignesConvention().getTypeCulture().getTypeCulture())
					.getResultList();
		}
		
		//On applique pas le filtre, toutes les variétés sont affichées
		else
		{
			return entityManager.createQuery("select variete.designation from Variete variete order by variete.designation asc").getResultList();
		}
		
	}
}
